Coverage for lupyne/engine/__init__: 100%

# Coverage for lupyne/engine/__init__ : 100%

## 10 statements 10 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | """ Pythonic wrapper around `PyLucene <http://lucene.apache.org/pylucene/>`_ search engine. Provides high-level interfaces to indexes and documents, abstracting away java lucene primitives. """ import warnings import lucene warnings.simplefilter('default', DeprecationWarning) from .queries import Query, SortField, TermsFilter from .documents import Document, Field, MapField, NestedField, DocValuesField, NumericField, DateTimeField from .indexers import TokenFilter, Analyzer, IndexSearcher, MultiSearcher, IndexWriter, Indexer, ParallelIndexer from .spatial import PointField, PolygonField assert lucene.VERSION >= '4.4' if lucene.VERSION < '4.6': warnings.warn('Support for lucene 4.4 and 4.5 will be removed in the next release.', DeprecationWarning)